+++
date = "2018-02-14"
weight = 100

title = "VirtualBox"

aliases = [
    "/old-wiki/VirtualBox"
]
+++

Oracle's VirtualBox is currently our recommended virtualization package
for running the SDK.

## VirtualBox Setup

1.  Download from the [Images]( {{< ref "/images.md" >}} ) repository the
    **.vdi.gz** for the SDK
2.  Expand the downloaded **.vdi.gz** file
3.  Create a new VM in the VirtualBox Manager
4.  Select *Use an existing virtual hard disk file* and chose the
    **.vdi** file
5.  Modify Settings
      - Set base memory: *System*→*Motherboard*→*Base Memory* (2048MB is
        recommended)
      - Check the *System*→*Motherboard*→*Enable EFI (special OSes
        only)* option (only for 64bit SDK image)
      - Check the *System*→*Processor*→*Enable PAE/NX* option
      - Set video memory: *Display*→*Screen*→*Video Memory* (64MB is
        recommended)
      - Be sure 3D Acceleration is **disabled**. Check the
        *Display*→*Screen*→*Enable 3D Acceleration* option
6.  Boot the VM

## From the command line

<code>

    RELEASE=18.03
    VDIFILE=~/apertis_18.03-sdk-amd64-sdk.vdi
    VMNAME="Apertis $RELEASE"

    vboxmanage createvm --name "$VMNAME" --ostype Ubuntu_64
    vboxmanage modifyvm "$VNMAME" --memory 2048 --apic on --pae on --largepages off --firmware efi --accelerate3d off --vram 64
    vboxmanage modifyvm --nictype1 virtio
    vboxmanage registervm "$HOME/VirtualBox VMs/$VMNAME/$VMNAME.vbox"
    vboxmanage storagectl "$VMNAME" --name SATA --add sata
    vboxmanage storageattach "$VMNAME" --storagectl SATA --port 0 --type hdd --medium "$VDIFILE"

    vboxsdl --startvm "$VMNAME"

</code>

## Guest Additions under VirtualBox SDK images

### What are the "Guest additions"?

  -
    Guest additions consist of device drivers and system applications
    that optimize the guest operating system for better performance and
    usability. They are designed to be installed inside a virtual
    machine after the guest operating system has been installed. For
    more information on the features provided by guest additions, see
    [this page](http://www.virtualbox.org/manual/ch04.html)

### Why should we install them?

  -
    In the context of the Apertis project, guest additions were selected
    to allow developers to enable fullscreen rendering within VirtualBox
    SDK images. Fullscreen is not the only reason to install guest
    additions, though. Shared folders are another very handy feature.

### Installation Guide

This concise step-by-step installation guide is intended for VirtualBox
**running our Linux Apertis SDK images**. Please install an up-to-date
version of VirtualBox on your Host system. Find the [binaries and
installation instructions
here](https://www.virtualbox.org/wiki/Linux_Downloads).

1.  Start your VirtualBox Apertis machine SDK image
2.  Click menu *Devices* → *Install Guest Additions*
3.  Double-click on the **VBOXADDITIONS** CD icon which should appear on
    your guest desktop
4.  Open a terminal window and type:
    `   `<code>
        sudo /media/user/VBOXADDITIONS_${VBox_version}_${VBox_build}/VBoxLinuxAdditions.run
    </code>
5.  Reboot your virtual machine
6.  Verify a new directory is created under `/opt` with guest additions
    or verify the `vboxguest` module is loaded

You can now enjoy guest additions' enhanced features.

## Non-SDK images

We recommend running minimal, target and development images on [real
hardware]( {{< ref "/reference_hardware/_index.md" >}} ), but VirtualBox can run our
**amd64** images.

1.  Download from the [Images]( {{< ref "/images.md" >}} ) repository the
    **.img.gz** and **.img.bmap** files for the image you need
2.  Expand the downloaded **.img.gz** file:
      - If you have **bmaptool** (recommended), use that to create a
        sparse file: **bmaptool copy filename.img.gz apertis.img**
      - If not, expand the downloaded **.img.gz** file (this will be
        slower)
3.  Convert the image to VirtualBox format: **VBoxManage convertfromraw
    apertis.img apertis.vdi --format VDI**
4.  You can delete the temporary **.img** file now
5.  Create a new VM in the VirtualBox Manager
6.  Select *Use an existing virtual hard disk file* and chose the
    **.vdi** file
7.  Modify Settings, mostly the same as for the SDK (see above)
      - *Base Memory* can be smaller for these images: 1024M is
        recommended
8.  Minimal images have limited hardware support to save space, so they
    need additional reconfiguration:
      - *Storage*→*Controller: IDE*→*Add Hard Disk*→Choose the **.vdi**
        file again
      - *Storage*→*Controller: SATA*→Remove the duplicate disk
      - *Network*→*Adapter 1*→*Advanced*→*Adapter Type* and choose
        *Paravirtualized Network (virtio-net)*

<li>

Boot the VM